/*
 * freee API
 *
 *  <h1 id=\"freee_api\">freee API</h1> <hr /> <h2 id=\"start_guide\">スタートガイド</h2>  <p>freee API開発がはじめての方は<a href=\"https://developer.freee.co.jp/getting-started\">freee API スタートガイド</a>を参照してください。</p>  <hr /> <h2 id=\"specification\">仕様</h2>  <h3 id=\"api_endpoint\">APIエンドポイント</h3>  <p>https://api.freee.co.jp/ (httpsのみ)</p>  <h3 id=\"about_authorize\">認証について</h3> <p>OAuth2.0を利用します。詳細は<a href=\"https://developer.freee.co.jp/docs\" target=\"_blank\">ドキュメントの認証</a>パートを参照してください。</p>  <h3 id=\"data_format\">データフォーマット</h3>  <p>リクエスト、レスポンスともにJSON形式をサポートしていますが、詳細は、API毎の説明欄（application/jsonなど）を確認してください。</p>  <h3 id=\"compatibility\">後方互換性ありの変更</h3>  <p>freeeでは、APIを改善していくために以下のような変更は後方互換性ありとして通知なく変更を入れることがあります。アプリケーション実装者は以下を踏まえて開発を行ってください。</p>  <ul> <li>新しいAPIリソース・エンドポイントの追加</li> <li>既存のAPIに対して必須ではない新しいリクエストパラメータの追加</li> <li>既存のAPIレスポンスに対する新しいプロパティの追加</li> <li>既存のAPIレスポンスに対するプロパティの順番の入れ変え</li> <li>keyとなっているidやcodeの長さの変更（長くする）</li> </ul>  <h3 id=\"common_response_header\">共通レスポンスヘッダー</h3>  <p>すべてのAPIのレスポンスには以下のHTTPヘッダーが含まれます。</p>  <ul> <li> <p>X-Freee-Request-ID</p> <ul> <li>各リクエスト毎に発行されるID</li> </ul> </li> </ul>  <h3 id=\"common_error_response\">共通エラーレスポンス</h3>  <ul> <li> <p>ステータスコードはレスポンス内のJSONに含まれる他、HTTPヘッダにも含まれる</p> </li> <li> <p>一部のエラーレスポンスにはエラーコードが含まれます。<br>詳細は、<a href=\"https://developer.freee.co.jp/tips/faq/40x-checkpoint\">HTTPステータスコード400台エラー時のチェックポイント</a>を参照してください</p> </li> <p>type</p>  <ul> <li>status : HTTPステータスコードの説明</li>  <li>validation : エラーの詳細の説明（開発者向け）</li> </ul> </li> </ul>  <p>レスポンスの例</p>  <pre><code>  {     &quot;status_code&quot; : 400,     &quot;errors&quot; : [       {         &quot;type&quot; : &quot;status&quot;,         &quot;messages&quot; : [&quot;不正なリクエストです。&quot;]       },       {         &quot;type&quot; : &quot;validation&quot;,         &quot;messages&quot; : [&quot;Date は不正な日付フォーマットです。入力例：2019-12-17&quot;]       }     ]   }</code></pre>  </br>  <h3 id=\"api_rate_limit\">API使用制限</h3>    <p>freeeは一定期間に過度のアクセスを検知した場合、APIアクセスをコントロールする場合があります。</p>   <p>その際のhttp status codeは403となります。制限がかかってから10分程度が過ぎると再度使用することができるようになります。</p>  <h4 id=\"reports_api_endpoint\">/reportsと/receipts/{id}/downloadエンドポイント</h4>  <p>freeeはエンドポイント毎に一定頻度以上のアクセスを検知した場合、APIアクセスをコントロールする場合があります。その際のhttp status codeは429（too many requests）となります。</p>  <ul>   <li>/reports:1秒に10回まで</li>   <li>/receipts/{id}/download:1秒に3回まで</li> </ul>  <p>レスポンスボディのmetaプロパティに以下を含めます。</p>  <ul>   <li>設定されている上限値</li>   <li>上限に達するまでの使用可能回数</li>   <li>（上限値に達した場合）使用回数がリセットされる時刻</li> </ul>  <h3 id=\"plan_api_rate_limit\">プラン別のAPI Rate Limit</h3>   <table border=\"1\">     <tbody>       <tr>         <th style=\"padding: 10px\"><strong>freee会計プラン名</strong></th>         <th style=\"padding: 10px\"><strong>事業所とアプリケーション毎に1日でのAPIコール数</strong></th>       </tr>       <tr>         <td style=\"padding: 10px\">エンタープライズ</td>         <td style=\"padding: 10px\">10,000</td>       </tr>       <tr>         <td style=\"padding: 10px\">プロフェッショナル</td>         <td style=\"padding: 10px\">5,000</td>       </tr>       <tr>         <td style=\"padding: 10px\">ベーシック</td>         <td style=\"padding: 10px\">3,000</td>       </tr>       <tr>         <td style=\"padding: 10px\">ミニマム</td>         <td style=\"padding: 10px\">3,000</td>       </tr>       <tr>         <td style=\"padding: 10px\">上記以外</td>         <td style=\"padding: 10px\">3,000</td>       </tr>     </tbody>   </table>  <h3 id=\"webhook\">Webhookについて</h3>  <p>詳細は<a href=\"https://developer.freee.co.jp/docs/accounting/webhook\" target=\"_blank\">会計Webhook概要</a>を参照してください。</p>  <hr /> <h2 id=\"contact\">連絡先</h2>  <p>ご不明点、ご要望等は <a href=\"https://support.freee.co.jp/hc/ja/requests/new\">freee サポートデスクへのお問い合わせフォーム</a> からご連絡ください。</p> <hr />&copy; Since 2013 freee K.K.
 *
 * The version of the OpenAPI document: v1.0
 * 
 * Generated by: https://openapi-generator.tech
 */




#[derive(Clone, Debug, PartialEq, Default, Serialize, Deserialize)]
pub struct AccountItemsResponseAccountItemsInner {
    /// 勘定科目ID
    #[serde(rename = "id")]
    pub id: i32,
    /// 勘定科目名 (30文字以内)
    #[serde(rename = "name")]
    pub name: String,
    /// 税区分コード
    #[serde(rename = "tax_code")]
    pub tax_code: i32,
    /// ショートカット1 (20文字以内)
    #[serde(rename = "shortcut", skip_serializing_if = "Option::is_none")]
    pub shortcut: Option<String>,
    /// ショートカット2(勘定科目コード) (20文字以内)
    #[serde(rename = "shortcut_num", skip_serializing_if = "Option::is_none")]
    pub shortcut_num: Option<String>,
    /// デフォルト設定がされている税区分ID
    #[serde(rename = "default_tax_id", skip_serializing_if = "Option::is_none")]
    pub default_tax_id: Option<i32>,
    /// デフォルト設定がされている税区分コード
    #[serde(rename = "default_tax_code")]
    pub default_tax_code: i32,
    /// 勘定科目カテゴリー
    #[serde(rename = "account_category")]
    pub account_category: String,
    /// 勘定科目のカテゴリーID
    #[serde(rename = "account_category_id")]
    pub account_category_id: i32,
    #[serde(rename = "categories")]
    pub categories: Vec<String>,
    /// 勘定科目の使用設定（true: 使用する、false: 使用しない）
    #[serde(rename = "available")]
    pub available: bool,
    /// 口座ID
    #[serde(rename = "walletable_id")]
    pub walletable_id: Option<i32>,
    /// 決算書表示名（小カテゴリー）
    #[serde(rename = "group_name", skip_serializing_if = "Option::is_none")]
    pub group_name: Option<String>,
    /// 収入取引相手勘定科目名
    #[serde(rename = "corresponding_income_name", skip_serializing_if = "Option::is_none")]
    pub corresponding_income_name: Option<String>,
    /// 収入取引相手勘定科目ID
    #[serde(rename = "corresponding_income_id", skip_serializing_if = "Option::is_none")]
    pub corresponding_income_id: Option<i32>,
    /// 支出取引相手勘定科目名
    #[serde(rename = "corresponding_expense_name", skip_serializing_if = "Option::is_none")]
    pub corresponding_expense_name: Option<String>,
    /// 支出取引相手勘定科目ID
    #[serde(rename = "corresponding_expense_id", skip_serializing_if = "Option::is_none")]
    pub corresponding_expense_id: Option<i32>,
}

impl AccountItemsResponseAccountItemsInner {
    pub fn new(id: i32, name: String, tax_code: i32, default_tax_code: i32, account_category: String, account_category_id: i32, categories: Vec<String>, available: bool, walletable_id: Option<i32>) -> AccountItemsResponseAccountItemsInner {
        AccountItemsResponseAccountItemsInner {
            id,
            name,
            tax_code,
            shortcut: None,
            shortcut_num: None,
            default_tax_id: None,
            default_tax_code,
            account_category,
            account_category_id,
            categories,
            available,
            walletable_id,
            group_name: None,
            corresponding_income_name: None,
            corresponding_income_id: None,
            corresponding_expense_name: None,
            corresponding_expense_id: None,
        }
    }
}


